GoogleCastOptions class

Configuration options for Google Cast functionality.

Implementers

Constructors

GoogleCastOptions({bool physicalVolumeButtonsWillControlDeviceVolume = true, bool disableDiscoveryAutostart = false, bool disableAnalyticsLogging = false, bool suspendSessionsWhenBackgrounded = true, bool stopReceiverApplicationWhenEndingSession = false, bool startDiscoveryAfterFirstTapOnCastButton = true, bool stopCastingOnAppTerminated = false})
Creates a new GoogleCastOptions instance.

Properties

disableAnalyticsLogging → bool
Whether to disable analytics logging.
final
disableDiscoveryAutostart → bool
Whether to disable discovery autostart.
final
hashCode → int
The hash code for this object.
no setterinherited
physicalVolumeButtonsWillControlDeviceVolume → bool
Whether physical volume buttons will control device volume.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDiscoveryAfterFirstTapOnCastButton → bool
Whether to start discovery after first tap on cast button.
final
stopCastingOnAppTerminated → bool
Whether to automatically stop casting and end the session when the app is killed/terminated.
final
stopReceiverApplicationWhenEndingSession → bool
Whether to stop receiver application when ending session.
final
suspendSessionsWhenBackgrounded → bool
Whether to suspend sessions when backgrounded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts this options object to a map representation.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited