GoogleCastQueueLoadOptions class

Configuration options for loading queue items in Google Cast.

Constructors

GoogleCastQueueLoadOptions({int startIndex = 0, Duration playPosition = Duration.zero, GoogleCastMediaRepeatMode repeatMode = GoogleCastMediaRepeatMode.off, Map<String, dynamic>? customData})
Creates a new GoogleCastQueueLoadOptions.

Properties

customData → Map<String, dynamic>?
Custom data to send with the request.
final
hashCode → int
The hash code for this object.
no setterinherited
playPosition → Duration
Position to start playback.
final
repeatMode → GoogleCastMediaRepeatMode
Repeat mode for the queue.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startIndex → int
Starting index in the queue.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap({bool android = false}) → Map<String, dynamic>
Converts these options to a map representation.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited