GoogleCastMediaTrack class

Represents a media track, including content type, ID, type, and serialization helpers.

Implementers

Constructors

GoogleCastMediaTrack({Map<String, dynamic>? customData, Rfc5646Language? language, String? name, TextTrackType? subtype, String? trackContentId, String? trackContentType, required int trackId, required TrackType type})
Creates a new GoogleCastMediaTrack instance.
GoogleCastMediaTrack.fromJson(String source)
Creates a GoogleCastMediaTrack from a JSON string.
factory
GoogleCastMediaTrack.fromMap(Map<String, dynamic> map)
Creates a GoogleCastMediaTrack from a map.
factory

Properties

customData → Map<String, dynamic>?
Custom data for the track.
final
hashCode → int
The hash code for this object.
no setterinherited
language → Rfc5646Language?
Language of the track.
final
name → String?
Name of the track.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype → TextTrackType?
Subtype of the track.
final
trackContentId → String?
Content ID of the track.
final
trackContentType → String?
Content type of the track.
final
trackId → int
Unique identifier of the track within the context of a MediaInfo object.
final
type → TrackType
The type of track.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
Converts the object to a JSON string.
toMap() → Map<String, dynamic>
Converts the object to a map for serialization.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited