IOSGoogleCastOptions constructor

IOSGoogleCastOptions(
  1. GoogleCastDiscoveryCriteriaInitialize _discoveryCriteria, {
  2. bool stopCastingOnAppTerminated = false,
})

Creates an instance of IOSGoogleCastOptions with the given discoveryCriteria.

stopCastingOnAppTerminated when set to true, will automatically stop casting and end the session when the app is killed/terminated. Defaults to false.

Implementation

IOSGoogleCastOptions(
  this._discoveryCriteria, {
  super.stopCastingOnAppTerminated,
});