GoogleCastVolume class

A widget that provides volume control for Google Cast devices.

This widget displays a volume icon that, when tapped, shows a popup with a slider to control the volume of the currently connected Cast device.

Inheritance

Constructors

GoogleCastVolume({Key? key, Color? iconColor, double? iconSize, Color? popupBackgroundColor, Color? sliderActiveColor, Color? sliderInactiveColor, Color? sliderThumbColor})
Creates a Google Cast volume control widget.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconColor → Color?
Color of the volume icon.
final
iconSize → double?
Size of the volume icon.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
popupBackgroundColor → Color?
Background color of the volume control popup.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sliderActiveColor → Color?
Color of the active portion of the volume slider.
final
sliderInactiveColor → Color?
Color of the inactive portion of the volume slider.
final
sliderThumbColor → Color?
Color of the volume slider thumb/handle.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<GoogleCastVolume>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited